use crate::{
    container_runtime::ContainerRuntimeState, grpc_client::GrpcClientState, state::ClientState,
};

#[derive(clap::Parser)]
pub struct SubscribeCommand {
    #[arg(long)]
    topic: String,
}

impl SubscribeCommand {
    pub async fn execute(&self, state: &ClientState) -> anyhow::Result<()> {
        let projects = state.grpc_client().subscribe(&self.topic).await?;

        let runtime = state.container_runtime();

        println!("printing found projects (len={})", projects.projects.len());
        for project in projects.projects {
            println!("project: {project:?}");

            runtime
                .ensure_running(
                    &project.name,
                    &format!("{}:{}", project.image, project.version),
                )
                .await?;
        }

        Ok(())
    }
}
